@@ -35,7 +35,11 @@ def blueprint_factory(config: Config):
                 page = f.read()
 
             def index(request, page):
-                return html(page.replace("__VERSION__", version))
+                return html(
+                    page.replace("__VERSION__", version).replace(
+                        "__URL_PREFIX__", getattr(config, "OAS_URL_PREFIX")
+                    )
+                )
 
             bp.add_route(partial(index, page=page), uri, name=ui)
             if config.OAS_UI_DEFAULT and config.OAS_UI_DEFAULT == ui:
@@ -92,7 +96,7 @@ def blueprint_factory(config: Config):
                     _handler = getattr(_handler.view_class, method.lower())
                 operation = OperationStore()[_handler]
 
-                if operation._exclude:
+                if operation._exclude or "openapi" in operation.tags:
                     continue
 
                 docstring = inspect.getdoc(_handler)
